@@ -1,5 +1,5 @@
 /*	MikMod sound library
-	(c) 1998, 1999 Miodrag Vallat and others - see file AUTHORS for
+	(c) 1998, 1999, 2000 Miodrag Vallat and others - see file AUTHORS for
 	complete list.
 
 	This library is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: virtch2.c,v 1.27 1999/06/28 03:00:06 miod Exp $
+  $Id: virtch2.c,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
 
   High-quality sample mixing routines, using a 32 bits mixing buffer,
   interpolation, and sample smoothing to improve sound quality and remove
@@ -39,11 +39,13 @@
 #include "config.h"
 #endif
 
-#include <mikmod_internals.h>
-  
-#include <stddef.h>
+#ifdef HAVE_MEMORY_H
+#include <memory.h>
+#endif
 #include <string.h>
 
+#include "mikmod_internals.h"
+  
 /*
    Constant Definitions
    ====================
@@ -588,7 +590,8 @@ static void AddChannel(SLONG* ptr,NATIVE todo)
 			}
 		} else {
 			/* The sample is playing forward */
-			if((vnf->flags & SF_LOOP) && (vnf->current >= idxlend)) {
+			if((vnf->flags & SF_LOOP) &&
+			   (vnf->current >= idxlend)) {
 				/* the sample is looping, check the loopend index */
 				if(vnf->flags & SF_BIDI) {
 					/* sample is doing bidirectional loops, so 'bounce' the
