@@ -1,6 +1,6 @@
 /*	MikMod sound library
-	(c) 1998, 1999 Miodrag Vallat and others - see file AUTHORS for
-	complete list.
+	(c) 1998, 1999, 2000 Miodrag Vallat and others - see file AUTHORS
+	for complete list.
 
 	This library is free software; you can redistribute it and/or modify
 	it under the terms of the GNU Library General Public License as
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: mikmod_build.h,v 1.5 1999/06/28 03:00:06 miod Exp $
+  $Id: mikmod_build.h,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
 
   MikMod sound library include file
 
@@ -36,20 +36,34 @@
 extern "C" {
 #endif
 
+/*
+ * ========== Compiler magic for shared libraries
+ */
+
+#if defined WIN32 && defined _DLL
+#ifdef DLL_EXPORTS
+#define MIKMODAPI __declspec(dllexport)
+#else
+#define MIKMODAPI __declspec(dllimport)
+#endif
+#else
+#define MIKMODAPI
+#endif
+
 /*
  *	========== Library version
  */
 
-#define LIBMIKMOD_VERSION_MAJOR 3
-#define LIBMIKMOD_VERSION_MINOR 1
-#define LIBMIKMOD_REVISION      7
+#define LIBMIKMOD_VERSION_MAJOR 3L
+#define LIBMIKMOD_VERSION_MINOR 1L
+#define LIBMIKMOD_REVISION      10L
 
 #define LIBMIKMOD_VERSION \
 	((LIBMIKMOD_VERSION_MAJOR<<16)| \
 	 (LIBMIKMOD_VERSION_MINOR<< 8)| \
 	 (LIBMIKMOD_REVISION))
 
-extern long MikMod_GetVersion(void);
+MIKMODAPI extern long MikMod_GetVersion(void);
 
 /*
  *	========== Platform independent-type definitions
@@ -59,6 +73,7 @@ extern long MikMod_GetVersion(void);
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <io.h>
+#include <mmsystem.h>
 #endif
 
 #if defined(__OS2__)||defined(__EMX__)
@@ -68,7 +83,9 @@ extern long MikMod_GetVersion(void);
 typedef char CHAR;
 #endif
 
-#if defined(__alpha)
+
+
+#if defined(__arch64__) || defined(__alpha)
 /* 64 bit architectures */
 
 typedef signed char     SBYTE;      /* 1 byte, signed */
@@ -119,8 +136,10 @@ enum {
 	MMERR_INVALID_DEVICE,
 	MMERR_INITIALIZING_MIXER,
 	MMERR_OPENING_AUDIO,
+	MMERR_8BIT_ONLY,
 	MMERR_16BIT_ONLY,
 	MMERR_STEREO_ONLY,
+	MMERR_ULAW,
 	MMERR_NON_BLOCK,
 
 	MMERR_AF_AUDIO_PORT,
@@ -152,7 +171,6 @@ enum {
 	MMERR_SGI_MONO,
 
 	MMERR_SUN_INIT,
-	MMERR_SUN_16BIT_ULAW,
 
 	MMERR_OS2_MIXSETUP,
 	MMERR_OS2_SEMAPHORE,
@@ -186,11 +204,11 @@ enum {
 typedef void (MikMod_handler)(void);
 typedef MikMod_handler *MikMod_handler_t;
 
-extern int  MikMod_errno;
-extern BOOL MikMod_critical;
-extern char *MikMod_strerror(int);
+MIKMODAPI extern int  MikMod_errno;
+MIKMODAPI extern BOOL MikMod_critical;
+MIKMODAPI extern char *MikMod_strerror(int);
 
-extern MikMod_handler_t MikMod_RegisterErrorHandler(MikMod_handler_t);
+MIKMODAPI extern MikMod_handler_t MikMod_RegisterErrorHandler(MikMod_handler_t);
 
 /*
  *	========== Library initialization and core functions
@@ -198,24 +216,24 @@ extern MikMod_handler_t MikMod_RegisterErrorHandler(MikMod_handler_t);
 
 struct MDRIVER;
 
-extern void   MikMod_RegisterAllDrivers(void);
+MIKMODAPI extern void   MikMod_RegisterAllDrivers(void);
 
-extern CHAR*  MikMod_InfoDriver(void);
-extern void   MikMod_RegisterDriver(struct MDRIVER*);
-extern int    MikMod_DriverFromAlias(CHAR*);
+MIKMODAPI extern CHAR*  MikMod_InfoDriver(void);
+MIKMODAPI extern void   MikMod_RegisterDriver(struct MDRIVER*);
+MIKMODAPI extern int    MikMod_DriverFromAlias(CHAR*);
 
-extern BOOL   MikMod_Init(CHAR*);
-extern void   MikMod_Exit(void);
-extern BOOL   MikMod_Reset(CHAR*);
-extern BOOL   MikMod_SetNumVoices(int,int);
-extern BOOL   MikMod_Active(void);
-extern BOOL   MikMod_EnableOutput(void);
-extern void   MikMod_DisableOutput(void);
-extern void   MikMod_Update(void);
+MIKMODAPI extern BOOL   MikMod_Init(CHAR*);
+MIKMODAPI extern void   MikMod_Exit(void);
+MIKMODAPI extern BOOL   MikMod_Reset(CHAR*);
+MIKMODAPI extern BOOL   MikMod_SetNumVoices(int,int);
+MIKMODAPI extern BOOL   MikMod_Active(void);
+MIKMODAPI extern BOOL   MikMod_EnableOutput(void);
+MIKMODAPI extern void   MikMod_DisableOutput(void);
+MIKMODAPI extern void   MikMod_Update(void);
 
-extern BOOL   MikMod_InitThreads(void);
-extern void   MikMod_Lock(void);
-extern void   MikMod_Unlock(void);
+MIKMODAPI extern BOOL   MikMod_InitThreads(void);
+MIKMODAPI extern void   MikMod_Lock(void);
+MIKMODAPI extern void   MikMod_Unlock(void);
 
 /*
  *	========== Reader, Writer
@@ -270,10 +288,12 @@ typedef struct MWRITER {
 #define SF_EXTRAPLAYBACKMASK	0x3000
 
 /* Panning constants */
-#define PAN_LEFT       0
-#define PAN_CENTER   128
-#define PAN_RIGHT    255
-#define PAN_SURROUND 512 /* panning value for Dolby Surround */
+#define PAN_LEFT		0
+#define PAN_HALFLEFT 	64
+#define PAN_CENTER		128
+#define PAN_HALFRIGHT	192
+#define PAN_RIGHT		255
+#define PAN_SURROUND	512 /* panning value for Dolby Surround */
 
 typedef struct SAMPLE {
 	SWORD  panning;     /* panning (0-255 or PAN_SURROUND) */
@@ -305,23 +325,23 @@ typedef struct SAMPLE {
 
 /* Sample functions */
 
-extern SAMPLE *Sample_Load(CHAR*);
-extern SAMPLE *Sample_LoadFP(FILE*);
-extern SAMPLE *Sample_LoadGeneric(MREADER*);
-extern void   Sample_Free(SAMPLE*);
-extern SBYTE  Sample_Play(SAMPLE*,ULONG,UBYTE);
+MIKMODAPI extern SAMPLE *Sample_Load(CHAR*);
+MIKMODAPI extern SAMPLE *Sample_LoadFP(FILE*);
+MIKMODAPI extern SAMPLE *Sample_LoadGeneric(MREADER*);
+MIKMODAPI extern void   Sample_Free(SAMPLE*);
+MIKMODAPI extern SBYTE  Sample_Play(SAMPLE*,ULONG,UBYTE);
 
-extern void   Voice_SetVolume(SBYTE,UWORD);
-extern UWORD  Voice_GetVolume(SBYTE);
-extern void   Voice_SetFrequency(SBYTE,ULONG);
-extern ULONG  Voice_GetFrequency(SBYTE);
-extern void   Voice_SetPanning(SBYTE,ULONG);
-extern ULONG  Voice_GetPanning(SBYTE);
-extern void   Voice_Play(SBYTE,SAMPLE*,ULONG);
-extern void   Voice_Stop(SBYTE);
-extern BOOL   Voice_Stopped(SBYTE);
-extern SLONG  Voice_GetPosition(SBYTE);
-extern ULONG  Voice_RealVolume(SBYTE);
+MIKMODAPI extern void   Voice_SetVolume(SBYTE,UWORD);
+MIKMODAPI extern UWORD  Voice_GetVolume(SBYTE);
+MIKMODAPI extern void   Voice_SetFrequency(SBYTE,ULONG);
+MIKMODAPI extern ULONG  Voice_GetFrequency(SBYTE);
+MIKMODAPI extern void   Voice_SetPanning(SBYTE,ULONG);
+MIKMODAPI extern ULONG  Voice_GetPanning(SBYTE);
+MIKMODAPI extern void   Voice_Play(SBYTE,SAMPLE*,ULONG);
+MIKMODAPI extern void   Voice_Stop(SBYTE);
+MIKMODAPI extern BOOL   Voice_Stopped(SBYTE);
+MIKMODAPI extern SLONG  Voice_GetPosition(SBYTE);
+MIKMODAPI extern ULONG  Voice_RealVolume(SBYTE);
 
 /*
  *	========== Internal module representation (UniMod)
@@ -393,16 +413,28 @@ typedef struct INSTRUMENT {
 struct MP_CONTROL;
 struct MP_VOICE;
 
+/*
+	Module definition
+*/
+
+/* maximum master channels supported */
+#define UF_MAXCHAN	64
+
 /* Module flags */
-#define UF_XMPERIODS 0x0001 /* XM periods / finetuning */
-#define UF_LINEAR    0x0002 /* LINEAR periods (UF_XMPERIODS must be set) */
-#define UF_INST      0x0004 /* Instruments are used */
-#define UF_NNA       0x0008 /* IT: NNA used, set numvoices rather than numchn */
-#define UF_S3MSLIDES 0x0010 /* uses old S3M volume slides */
-#define UF_BGSLIDES  0x0020 /* continue volume slides in the background */
-#define UF_HIGHBPM   0x0040 /* MED: can use >255 bpm */
-#define UF_NOWRAP    0x0080 /* XM-type (i.e. illogical) pattern brk semantics */
-#define UF_ARPMEM    0x0100 /* IT: need arpeggio memory */
+#define UF_XMPERIODS	0x0001 /* XM periods / finetuning */
+#define UF_LINEAR		0x0002 /* LINEAR periods (UF_XMPERIODS must be set) */
+#define UF_INST			0x0004 /* Instruments are used */
+#define UF_NNA			0x0008 /* IT: NNA used, set numvoices rather
+								  than numchn */
+#define UF_S3MSLIDES	0x0010 /* uses old S3M volume slides */
+#define UF_BGSLIDES		0x0020 /* continue volume slides in the background */
+#define UF_HIGHBPM		0x0040 /* MED: can use >255 bpm */
+#define UF_NOWRAP		0x0080 /* XM-type (i.e. illogical) pattern break
+								  semantics */
+#define UF_ARPMEM		0x0100 /* IT: need arpeggio memory */
+#define UF_FT2QUIRKS	0x0200 /* emulate some FT2 replay quirks */
+#define UF_PANNING		0x0400 /* module uses panning effects or have
+								  non-tracker default initial panning */
 
 typedef struct MODULE {
 	/* general module information */
@@ -420,14 +452,15 @@ typedef struct MODULE {
 struct  INSTRUMENT* instruments; /* all instruments */
 struct  SAMPLE*     samples;     /* all samples */
 		UBYTE       realchn;     /* real number of channels used */
+		UBYTE       totalchn;    /* total number of channels used (incl NNAs) */
 
 	/* playback settings */
 		UWORD       reppos;      /* restart position */
 		UBYTE       initspeed;   /* initial song speed */
 		UWORD       inittempo;   /* initial song tempo */
 		UBYTE       initvolume;  /* initial global volume (0 - 128) */
-		UWORD       panning[64]; /* 64 panning positions */
-		UBYTE       chanvol[64]; /* 64 channel positions */
+		UWORD       panning[UF_MAXCHAN]; /* panning positions */
+		UBYTE       chanvol[UF_MAXCHAN]; /* channel positions */
 		UWORD       bpm;         /* current beats-per-minute speed */
 		UWORD       sngspd;      /* current song speed */
 		SWORD       volume;      /* song volume (0-128) (or user volume) */
@@ -465,6 +498,7 @@ struct MP_VOICE*    voice;       /* Audio Voice information (size md_numchn) */
 		UBYTE       patdly;      /* patterndelay counter (command memory) */
 		UBYTE       patdly2;     /* patterndelay counter (real one) */
 		SWORD       posjmp;      /* flag to indicate a jump is needed... */
+		UWORD		bpmlimit;	 /* threshold to detect bpm or speed values */
 } MODULE;
 
 /*
@@ -473,60 +507,62 @@ struct MP_VOICE*    voice;       /* Audio Voice information (size md_numchn) */
 
 struct MLOADER;
 
-extern CHAR*   MikMod_InfoLoader(void);
-extern void    MikMod_RegisterAllLoaders(void);
-extern void    MikMod_RegisterLoader(struct MLOADER*);
+MIKMODAPI extern CHAR*   MikMod_InfoLoader(void);
+MIKMODAPI extern void    MikMod_RegisterAllLoaders(void);
+MIKMODAPI extern void    MikMod_RegisterLoader(struct MLOADER*);
 
-extern struct MLOADER load_669; /* 669 and Extended-669 (by Tran/Renaissance) */
-extern struct MLOADER load_amf; /* DMP Advanced Module Format (by Otto Chrons) */
-extern struct MLOADER load_dsm; /* DSIK internal module format */
-extern struct MLOADER load_far; /* Farandole Composer (by Daniel Potter) */
-extern struct MLOADER load_gdm; /* General DigiMusic (by Edward Schlunder) */
-extern struct MLOADER load_it;  /* Impulse Tracker (by Jeffrey Lim) */
-extern struct MLOADER load_imf; /* Imago Orpheus (by Lutz Roeder) */
-extern struct MLOADER load_med; /* Amiga MED modules (by Teijo Kinnunen) */
-extern struct MLOADER load_m15; /* Soundtracker 15-instrument */
-extern struct MLOADER load_mod; /* Standard 31-instrument Module loader */
-extern struct MLOADER load_mtm; /* Multi-Tracker Module (by Renaissance) */
-extern struct MLOADER load_stm; /* ScreamTracker 2 (by Future Crew) */
-extern struct MLOADER load_stx; /* STMIK 0.2 (by Future Crew) */
-extern struct MLOADER load_s3m; /* ScreamTracker 3 (by Future Crew) */
-extern struct MLOADER load_ult; /* UltraTracker  (by MAS) */
-extern struct MLOADER load_uni; /* MikMod and APlayer internal module format */
-extern struct MLOADER load_xm;  /* FastTracker 2 (by Triton) */
+MIKMODAPI extern struct MLOADER load_669; /* 669 and Extended-669 (by Tran/Renaissance) */
+MIKMODAPI extern struct MLOADER load_amf; /* DMP Advanced Module Format (by Otto Chrons) */
+MIKMODAPI extern struct MLOADER load_dsm; /* DSIK internal module format */
+MIKMODAPI extern struct MLOADER load_far; /* Farandole Composer (by Daniel Potter) */
+MIKMODAPI extern struct MLOADER load_gdm; /* General DigiMusic (by Edward Schlunder) */
+MIKMODAPI extern struct MLOADER load_it;  /* Impulse Tracker (by Jeffrey Lim) */
+MIKMODAPI extern struct MLOADER load_imf; /* Imago Orpheus (by Lutz Roeder) */
+MIKMODAPI extern struct MLOADER load_med; /* Amiga MED modules (by Teijo Kinnunen) */
+MIKMODAPI extern struct MLOADER load_m15; /* Soundtracker 15-instrument */
+MIKMODAPI extern struct MLOADER load_mod; /* Standard 31-instrument Module loader */
+MIKMODAPI extern struct MLOADER load_mtm; /* Multi-Tracker Module (by Renaissance) */
+MIKMODAPI extern struct MLOADER load_okt; /* Amiga Oktalyzer */
+MIKMODAPI extern struct MLOADER load_stm; /* ScreamTracker 2 (by Future Crew) */
+MIKMODAPI extern struct MLOADER load_stx; /* STMIK 0.2 (by Future Crew) */
+MIKMODAPI extern struct MLOADER load_s3m; /* ScreamTracker 3 (by Future Crew) */
+MIKMODAPI extern struct MLOADER load_ult; /* UltraTracker (by MAS) */
+MIKMODAPI extern struct MLOADER load_uni; /* MikMod and APlayer internal module format */
+MIKMODAPI extern struct MLOADER load_xm;  /* FastTracker 2 (by Triton) */
 
 /*
  *	========== Module player
  */
 
-extern MODULE* Player_Load(CHAR*,int,BOOL);
-extern MODULE* Player_LoadFP(FILE*,int,BOOL);
-extern MODULE* Player_LoadGeneric(MREADER*,int,BOOL);
-extern CHAR*   Player_LoadTitle(CHAR*);
-extern void    Player_Free(MODULE*);
-extern void    Player_Start(MODULE*);
-extern BOOL    Player_Active(void);
-extern void    Player_Stop(void);
-extern void    Player_TogglePause(void);
-extern BOOL    Player_Paused(void);
-extern void    Player_NextPosition(void);
-extern void    Player_PrevPosition(void);
-extern void    Player_SetPosition(UWORD);
-extern BOOL    Player_Muted(UBYTE);
-extern void    Player_SetVolume(SWORD);
-extern MODULE* Player_GetModule(void);
-extern void    Player_SetSpeed(UWORD);
-extern void    Player_SetTempo(UWORD);
-extern void    Player_Unmute(SLONG,...);
-extern void    Player_Mute(SLONG,...);
-extern void    Player_ToggleMute(SLONG,...);
-extern int     Player_GetChannelVoice(UBYTE);
-extern UWORD   Player_GetChannelPeriod(UBYTE);
+MIKMODAPI extern MODULE* Player_Load(CHAR*,int,BOOL);
+MIKMODAPI extern MODULE* Player_LoadFP(FILE*,int,BOOL);
+MIKMODAPI extern MODULE* Player_LoadGeneric(MREADER*,int,BOOL);
+MIKMODAPI extern CHAR*   Player_LoadTitle(CHAR*);
+MIKMODAPI extern CHAR*   Player_LoadTitleFP(FILE*);
+MIKMODAPI extern void    Player_Free(MODULE*);
+MIKMODAPI extern void    Player_Start(MODULE*);
+MIKMODAPI extern BOOL    Player_Active(void);
+MIKMODAPI extern void    Player_Stop(void);
+MIKMODAPI extern void    Player_TogglePause(void);
+MIKMODAPI extern BOOL    Player_Paused(void);
+MIKMODAPI extern void    Player_NextPosition(void);
+MIKMODAPI extern void    Player_PrevPosition(void);
+MIKMODAPI extern void    Player_SetPosition(UWORD);
+MIKMODAPI extern BOOL    Player_Muted(UBYTE);
+MIKMODAPI extern void    Player_SetVolume(SWORD);
+MIKMODAPI extern MODULE* Player_GetModule(void);
+MIKMODAPI extern void    Player_SetSpeed(UWORD);
+MIKMODAPI extern void    Player_SetTempo(UWORD);
+MIKMODAPI extern void    Player_Unmute(SLONG,...);
+MIKMODAPI extern void    Player_Mute(SLONG,...);
+MIKMODAPI extern void    Player_ToggleMute(SLONG,...);
+MIKMODAPI extern int     Player_GetChannelVoice(UBYTE);
+MIKMODAPI extern UWORD   Player_GetChannelPeriod(UBYTE);
 
 typedef void (MikMod_player)(void);
 typedef MikMod_player *MikMod_player_t;
 
-extern MikMod_player_t MikMod_RegisterPlayer(MikMod_player_t);
+MIKMODAPI extern MikMod_player_t MikMod_RegisterPlayer(MikMod_player_t);
 
 #define MUTE_EXCLUSIVE  32000
 #define MUTE_INCLUSIVE  32001
@@ -597,79 +633,80 @@ struct MDRIVER* next;
 } MDRIVER;
 
 /* These variables can be changed at ANY time and results will be immediate */
-extern UBYTE md_volume;      /* global sound volume (0-128) */
-extern UBYTE md_musicvolume; /* volume of song */
-extern UBYTE md_sndfxvolume; /* volume of sound effects */
-extern UBYTE md_reverb;      /* 0 = none;  15 = chaos */
-extern UBYTE md_pansep;      /* 0 = mono;  128 == 100% (full left/right) */
+MIKMODAPI extern UBYTE md_volume;      /* global sound volume (0-128) */
+MIKMODAPI extern UBYTE md_musicvolume; /* volume of song */
+MIKMODAPI extern UBYTE md_sndfxvolume; /* volume of sound effects */
+MIKMODAPI extern UBYTE md_reverb;      /* 0 = none;  15 = chaos */
+MIKMODAPI extern UBYTE md_pansep;      /* 0 = mono;  128 == 100% (full left/right) */
 
 /* The variables below can be changed at any time, but changes will not be
    implemented until MikMod_Reset is called. A call to MikMod_Reset may result
    in a skip or pop in audio (depending on the soundcard driver and the settings
    changed). */
-extern UWORD md_device;      /* device */
-extern UWORD md_mixfreq;     /* mixing frequency */
-extern UWORD md_mode;        /* mode. See DMODE_? flags above */
+MIKMODAPI extern UWORD md_device;      /* device */
+MIKMODAPI extern UWORD md_mixfreq;     /* mixing frequency */
+MIKMODAPI extern UWORD md_mode;        /* mode. See DMODE_? flags above */
 
 /* The following variable should not be changed! */
-extern MDRIVER* md_driver;   /* Current driver in use. */
+MIKMODAPI extern MDRIVER* md_driver;   /* Current driver in use. */
 
 /* Known drivers list */
 
-extern struct MDRIVER drv_nos;    /* no sound */
-extern struct MDRIVER drv_pipe;   /* piped output */
-extern struct MDRIVER drv_raw;    /* raw file disk writer [music.raw] */
-extern struct MDRIVER drv_stdout; /* output to stdout */
-extern struct MDRIVER drv_wav;    /* RIFF WAVE file disk writer [music.wav] */
+MIKMODAPI extern struct MDRIVER drv_nos;    /* no sound */
+MIKMODAPI extern struct MDRIVER drv_pipe;   /* piped output */
+MIKMODAPI extern struct MDRIVER drv_raw;    /* raw file disk writer [music.raw] */
+MIKMODAPI extern struct MDRIVER drv_stdout; /* output to stdout */
+MIKMODAPI extern struct MDRIVER drv_wav;    /* RIFF WAVE file disk writer [music.wav] */
 
-extern struct MDRIVER drv_ultra;  /* Linux Ultrasound driver */
+MIKMODAPI extern struct MDRIVER drv_ultra;  /* Linux Ultrasound driver */
+MIKMODAPI extern struct MDRIVER drv_sam9407;	/* Linux sam9407 driver */
 
-extern struct MDRIVER drv_AF;     /* Dec Alpha AudioFile */
-extern struct MDRIVER drv_aix;    /* AIX audio device */
-extern struct MDRIVER drv_alsa;   /* Advanced Linux Sound Architecture (ALSA) */
-extern struct MDRIVER drv_esd;    /* Enlightened sound daemon (EsounD) */
-extern struct MDRIVER drv_hp;     /* HP-UX audio device */
-extern struct MDRIVER drv_oss;    /* OpenSound System (Linux,FreeBSD...) */
-extern struct MDRIVER drv_sgi;    /* SGI audio library */
-extern struct MDRIVER drv_sun;    /* Sun/NetBSD/OpenBSD audio device */
+MIKMODAPI extern struct MDRIVER drv_AF;     /* Dec Alpha AudioFile */
+MIKMODAPI extern struct MDRIVER drv_aix;    /* AIX audio device */
+MIKMODAPI extern struct MDRIVER drv_alsa;   /* Advanced Linux Sound Architecture (ALSA) */
+MIKMODAPI extern struct MDRIVER drv_esd;    /* Enlightened sound daemon (EsounD) */
+MIKMODAPI extern struct MDRIVER drv_hp;     /* HP-UX audio device */
+MIKMODAPI extern struct MDRIVER drv_oss;    /* OpenSound System (Linux,FreeBSD...) */
+MIKMODAPI extern struct MDRIVER drv_sgi;    /* SGI audio library */
+MIKMODAPI extern struct MDRIVER drv_sun;    /* Sun/NetBSD/OpenBSD audio device */
 
-extern struct MDRIVER drv_dart;   /* OS/2 Direct Audio RealTime */
-extern struct MDRIVER drv_os2;    /* OS/2 MMPM/2 */
+MIKMODAPI extern struct MDRIVER drv_dart;   /* OS/2 Direct Audio RealTime */
+MIKMODAPI extern struct MDRIVER drv_os2;    /* OS/2 MMPM/2 */
 
-extern struct MDRIVER drv_ds;     /* Win32 DirectSound driver */
-extern struct MDRIVER drv_win;    /* Win32 multimedia API driver */
+MIKMODAPI extern struct MDRIVER drv_ds;     /* Win32 DirectSound driver */
+MIKMODAPI extern struct MDRIVER drv_win;    /* Win32 multimedia API driver */
 
-extern struct MDRIVER drv_mac;    /* Macintosh Sound Manager driver */
+MIKMODAPI extern struct MDRIVER drv_mac;    /* Macintosh Sound Manager driver */
 
 /*========== Virtual channel mixer interface (for user-supplied drivers only) */
 
-extern BOOL  VC_Init(void);
-extern void  VC_Exit(void);
-extern BOOL  VC_SetNumVoices(void);
-extern ULONG VC_SampleSpace(int);
-extern ULONG VC_SampleLength(int,SAMPLE*);
+MIKMODAPI extern BOOL  VC_Init(void);
+MIKMODAPI extern void  VC_Exit(void);
+MIKMODAPI extern BOOL  VC_SetNumVoices(void);
+MIKMODAPI extern ULONG VC_SampleSpace(int);
+MIKMODAPI extern ULONG VC_SampleLength(int,SAMPLE*);
 
-extern BOOL  VC_PlayStart(void);
-extern void  VC_PlayStop(void);
+MIKMODAPI extern BOOL  VC_PlayStart(void);
+MIKMODAPI extern void  VC_PlayStop(void);
 
-extern SWORD VC_SampleLoad(struct SAMPLOAD*,int);
-extern void  VC_SampleUnload(SWORD);
+MIKMODAPI extern SWORD VC_SampleLoad(struct SAMPLOAD*,int);
+MIKMODAPI extern void  VC_SampleUnload(SWORD);
 
-extern ULONG VC_WriteBytes(SBYTE*,ULONG);
-extern ULONG VC_SilenceBytes(SBYTE*,ULONG);
+MIKMODAPI extern ULONG VC_WriteBytes(SBYTE*,ULONG);
+MIKMODAPI extern ULONG VC_SilenceBytes(SBYTE*,ULONG);
 
-extern void  VC_VoiceSetVolume(UBYTE,UWORD);
-extern UWORD VC_VoiceGetVolume(UBYTE);
-extern void  VC_VoiceSetFrequency(UBYTE,ULONG);
-extern ULONG VC_VoiceGetFrequency(UBYTE);
-extern void  VC_VoiceSetPanning(UBYTE,ULONG);
-extern ULONG VC_VoiceGetPanning(UBYTE);
-extern void  VC_VoicePlay(UBYTE,SWORD,ULONG,ULONG,ULONG,ULONG,UWORD);
+MIKMODAPI extern void  VC_VoiceSetVolume(UBYTE,UWORD);
+MIKMODAPI extern UWORD VC_VoiceGetVolume(UBYTE);
+MIKMODAPI extern void  VC_VoiceSetFrequency(UBYTE,ULONG);
+MIKMODAPI extern ULONG VC_VoiceGetFrequency(UBYTE);
+MIKMODAPI extern void  VC_VoiceSetPanning(UBYTE,ULONG);
+MIKMODAPI extern ULONG VC_VoiceGetPanning(UBYTE);
+MIKMODAPI extern void  VC_VoicePlay(UBYTE,SWORD,ULONG,ULONG,ULONG,ULONG,UWORD);
 
-extern void  VC_VoiceStop(UBYTE);
-extern BOOL  VC_VoiceStopped(UBYTE);
-extern SLONG VC_VoiceGetPosition(UBYTE);
-extern ULONG VC_VoiceRealVolume(UBYTE);
+MIKMODAPI extern void  VC_VoiceStop(UBYTE);
+MIKMODAPI extern BOOL  VC_VoiceStopped(UBYTE);
+MIKMODAPI extern SLONG VC_VoiceGetPosition(UBYTE);
+MIKMODAPI extern ULONG VC_VoiceRealVolume(UBYTE);
 
 #ifdef __cplusplus
 }
